@@ -4,7 +4,9 @@
 
 #include <stdio.h>
 
-class CCL;
+ZEEK_FORWARD_DECLARE_NAMESPACED(CCL, zeek::detail);
+
+namespace zeek::detail {
 
 class EquivClass {
 public:
@@ -20,7 +22,7 @@ public:
 
 	void ConvertCCL(CCL* ccl);
 
-	int IsRep(int sym) const		{ return rep[sym] == sym; }
+	bool IsRep(int sym) const		{ return rep[sym] == sym; }
 	int EquivRep(int sym) const		{ return rep[sym]; }
 	int SymEquivClass(int sym) const	{ return equiv_class[sym]; }
 	int* EquivClasses() const		{ return equiv_class; }
@@ -41,3 +43,5 @@ protected:
 	int* ccl_flags;
 	int ec_nil, no_class, no_rep;
 };
+
+} // namespace zeek::detail
