@@ -1,10 +1,13 @@
+#warning "This file will be removed in v4.1. The code here is unused by Zeek. Notify a Zeek team member if your plugins are using this code."
+
 // See the file "COPYING" in the main distribution directory for copyright.
 
 #pragma once
 
+#include <sys/types.h> // for u_char
 #include <pcap.h>
 
-#include <sys/types.h> // for u_char
+namespace zeek::detail {
 
 class PacketDumper {
 public:
@@ -19,3 +22,5 @@ protected:
 
 	void SortTimeStamp(struct timeval* timestamp);
 };
+
+} // namespace zeek::detail
