@@ -2,16 +2,16 @@
 
 #pragma once
 
-#include "NetVar.h"
-#include "analyzer/protocol/tcp/TCP.h"
+#include "zeek/NetVar.h"
+#include "zeek/analyzer/protocol/tcp/TCP.h"
+#include "zeek/IPAddr.h"
+
 #include "analyzer/protocol/dce-rpc/events.bif.h"
-#include "IPAddr.h"
+#include "analyzer/protocol/dce-rpc/dce_rpc_pac.h"
 
-#include "dce_rpc_pac.h"
+namespace zeek::analyzer::dce_rpc {
 
-namespace analyzer { namespace dce_rpc {
-
-class DCE_RPC_Analyzer : public tcp::TCP_ApplicationAnalyzer {
+class DCE_RPC_Analyzer final : public analyzer::tcp::TCP_ApplicationAnalyzer {
 public:
 	explicit DCE_RPC_Analyzer(Connection* conn);
 	~DCE_RPC_Analyzer() override;
@@ -32,4 +32,10 @@ protected:
 	binpac::DCE_RPC::DCE_RPC_Conn* interp;
 };
 
-} } // namespace analyzer::*
+} // namespace zeek::analyzer::dce_rpc
+
+namespace analyzer::dce_rpc {
+
+using DCE_RPC_Analyzer [[deprecated("Remove in v4.1. Use zeek::analyzer::dce_rpc::DCE_RPC_Analyzer.")]] = zeek::analyzer::dce_rpc::DCE_RPC_Analyzer;
+
+} // namespace analyzer::dce_rpc
