@@ -4,13 +4,14 @@
 
 // for std::transform
 #include <algorithm>
-#include "analyzer/protocol/tcp/TCP.h"
 
-#include "imap_pac.h"
+#include "zeek/analyzer/protocol/tcp/TCP.h"
 
-namespace analyzer { namespace imap {
+#include "analyzer/protocol/imap/imap_pac.h"
 
-class IMAP_Analyzer : public tcp::TCP_ApplicationAnalyzer {
+namespace zeek::analyzer::imap {
+
+class IMAP_Analyzer final : public analyzer::tcp::TCP_ApplicationAnalyzer {
 public:
 	explicit IMAP_Analyzer(Connection* conn);
 	~IMAP_Analyzer() override;
@@ -19,7 +20,7 @@ public:
 	void DeliverStream(int len, const u_char* data, bool orig) override;
 	void Undelivered(uint64_t seq, int len, bool orig) override;
 
-	// Overriden from tcp::TCP_ApplicationAnalyzer.
+	// Overriden from analyzer::tcp::TCP_ApplicationAnalyzer.
 	void EndpointEOF(bool is_orig) override;
 
 	void StartTLS();
@@ -34,4 +35,10 @@ protected:
 	bool tls_active;
 };
 
-} } // namespace analyzer::*
+} // namespace zeek::analyzer::imap
+
+namespace analyzer::imap {
+
+using IMAP_Analyzer [[deprecated("Remove in v4.1. Use zeek::analyzer::imap::IMAP_Analyzer.")]] = zeek::analyzer::imap::IMAP_Analyzer;
+
+} // namespace analyzer::imap
