@@ -1,11 +1,12 @@
 #pragma once
 
-#include "analyzer/protocol/tcp/TCP.h"
-#include "modbus_pac.h"
+#include "zeek/analyzer/protocol/tcp/TCP.h"
 
-namespace analyzer { namespace modbus {
+#include "analyzer/protocol/modbus/modbus_pac.h"
 
-class ModbusTCP_Analyzer : public tcp::TCP_ApplicationAnalyzer {
+namespace zeek::analyzer::modbus {
+
+class ModbusTCP_Analyzer : public analyzer::tcp::TCP_ApplicationAnalyzer {
 public:
 	explicit ModbusTCP_Analyzer(Connection* conn);
 	~ModbusTCP_Analyzer() override;
@@ -23,4 +24,10 @@ protected:
 	binpac::ModbusTCP::ModbusTCP_Conn* interp;
 };
 
-} } // namespace analyzer::* 
+} // namespace zeek::analyzer::modbus
+
+namespace analyzer::modbus {
+
+using ModbusTCP_Analyzer [[deprecated("Remove in v4.1. Use zeek::analyzer::modbus::ModbusTCP_Analyzer.")]] = zeek::analyzer::modbus::ModbusTCP_Analyzer;
+
+} // namespace analyzer::modbus
