@@ -1,5 +1,9 @@
 #pragma once
 
+#include <memory>
+#include <string>
+#include <unordered_map>
+
 #include <broker/topic.hh>
 #include <broker/data.hh>
 #include <broker/store.hh>
@@ -8,25 +12,32 @@
 #include <broker/endpoint.hh>
 #include <broker/endpoint_info.hh>
 #include <broker/peer_info.hh>
+#include <broker/publisher_id.hh>
 #include <broker/backend.hh>
 #include <broker/backend_options.hh>
 #include <broker/detail/hash.hh>
 #include <broker/zeek.hh>
 
-#include <memory>
-#include <string>
-#include <unordered_map>
+#include "zeek/IntrusivePtr.h"
+#include "zeek/iosource/IOSource.h"
+#include "zeek/logging/WriterBackend.h"
 
-#include "NetVar.h"
-#include "iosource/IOSource.h"
-#include "logging/WriterBackend.h"
+ZEEK_FORWARD_DECLARE_NAMESPACED(Func, zeek);
+ZEEK_FORWARD_DECLARE_NAMESPACED(Frame, zeek::detail);
+ZEEK_FORWARD_DECLARE_NAMESPACED(VectorType, zeek);
+ZEEK_FORWARD_DECLARE_NAMESPACED(TableVal, zeek);
 
-class Frame;
+namespace zeek {
+using VectorTypePtr = IntrusivePtr<VectorType>;
+using TableValPtr = IntrusivePtr<TableVal>;
 
-namespace bro_broker {
+namespace Broker {
 
+namespace detail {
 class StoreHandleVal;
 class StoreQueryCallback;
+};
+
 class BrokerState;
 
 /**
@@ -64,7 +75,7 @@ public:
 	/**
 	 * Constructor.
 	 */
-	Manager(bool reading_pcaps);
+	Manager(bool use_real_time);
 
 	/**
 	 * Destructor.
@@ -77,9 +88,6 @@ public:
 	 */
 	void InitPostScript();
 
-	void ZeekInitDone()
-		{ after_zeek_init = true; }
-
 	/**
 	 * Shuts Broker down at termination.
 	 */
@@ -194,8 +202,9 @@ public:
 	 * See the Broker::SendFlags record type.
 	 * @return true if the message is sent successfully.
 	 */
-	bool PublishLogWrite(EnumVal* stream, EnumVal* writer, string path, int num_vals,
-			     const threading::Value* const * vals);
+	bool PublishLogWrite(EnumVal* stream, EnumVal* writer,
+	                     std::string path, int num_vals,
+	                     const threading::Value* const * vals);
 
 	/**
 	 * Automatically send an event to any interested peers whenever it is
@@ -224,7 +233,7 @@ public:
 	 * @return an `Event` record value.  If an invalid event or arguments
 	 * were supplied the optional "name" field will not be set.
 	 */
-	RecordVal* MakeEvent(val_list* args, Frame* frame);
+	RecordVal* MakeEvent(ValPList* args, zeek::detail::Frame* frame);
 
 	/**
 	 * Register interest in peer event messages that use a certain topic prefix.
@@ -261,8 +270,8 @@ public:
 	 * @param opts The backend options.
 	 * @return a pointer to the newly created store a nullptr on failure.
 	 */
-	StoreHandleVal* MakeMaster(const std::string& name, broker::backend type,
-	                           broker::backend_options opts);
+	detail::StoreHandleVal* MakeMaster(const std::string& name, broker::backend type,
+	                                   broker::backend_options opts);
 
 	/**
 	 * Create a new *clone* data store.
@@ -282,17 +291,28 @@ public:
 	 * the master.  A negative/zero value indicates to never buffer commands.
 	 * @return a pointer to the newly created store a nullptr on failure.
 	 */
-	StoreHandleVal* MakeClone(const std::string& name,
-	                          double resync_interval = 10.0,
-	                          double stale_interval = 300.0,
-	                          double mutation_buffer_interval = 120.0);
+	detail::StoreHandleVal* MakeClone(const std::string& name,
+	                                  double resync_interval = 10.0,
+	                                  double stale_interval = 300.0,
+	                                  double mutation_buffer_interval = 120.0);
 
 	/**
 	 * Lookup a data store by it's identifier name and type.
 	 * @param name the store's name.
 	 * @return a pointer to the store handle if it exists else nullptr.
 	 */
-	StoreHandleVal* LookupStore(const std::string& name);
+	detail::StoreHandleVal* LookupStore(const std::string& name);
+
+	/**
+	 * Register a Zeek table that is associated with a Broker store that is backing it. This
+	 * causes all changes that happen to the Broker store in the future to be applied to theZzeek
+	 * table.
+	 * A single Broker store can only be forwarded to a single table.
+	 * @param name name of the Broker store.
+	 * @param table pointer to the table/set that is being backed.
+	 * @return true on success, false if the named store is already being forwarded.
+	 */
+	bool AddForwardedStore(const std::string& name, TableValPtr table);
 
 	/**
 	 * Close and unregister a data store.  Any existing references to the
@@ -307,8 +327,8 @@ public:
 	 * @param cb the callback info to use when the query completes or times out.
 	 * @return true if now tracking a data store query.
 	 */
-	bool TrackStoreQuery(StoreHandleVal* handle, broker::request_id id,
-	                     StoreQueryCallback* cb);
+	bool TrackStoreQuery(detail::StoreHandleVal* handle, broker::request_id id,
+	                     detail::StoreQueryCallback* cb);
 
 	/**
 	 * Send all pending log write messages.
@@ -316,6 +336,11 @@ public:
 	 */
 	size_t FlushLogBuffers();
 
+	/**
+	 * Flushes all pending data store queries and also clears all contents.
+	 */
+	void ClearStores();
+
 	/**
 	 * @return communication statistics.
 	 */
@@ -334,14 +359,25 @@ public:
 private:
 
 	void DispatchMessage(const broker::topic& topic, broker::data msg);
+	// Process events used for Broker store backed zeek tables
+	void ProcessStoreEvent(broker::data msg);
+	// Common functionality for processing insert and update events.
+	void ProcessStoreEventInsertUpdate(const TableValPtr& table, const std::string& store_id, const broker::data& key, const broker::data& data, const broker::data& old_value, bool insert);
 	void ProcessEvent(const broker::topic& topic, broker::zeek::Event ev);
 	bool ProcessLogCreate(broker::zeek::LogCreate lc);
 	bool ProcessLogWrite(broker::zeek::LogWrite lw);
 	bool ProcessIdentifierUpdate(broker::zeek::IdentifierUpdate iu);
-	void ProcessStatus(broker::status stat);
-	void ProcessError(broker::error err);
-	void ProcessStoreResponse(StoreHandleVal*, broker::store::response response);
+	void ProcessStatus(broker::status_view stat);
+	void ProcessError(broker::error_view err);
+	void ProcessStoreResponse(detail::StoreHandleVal*, broker::store::response response);
 	void FlushPendingQueries();
+	// Initializes the masters for Broker backed Zeek tables when using the &backend attribute
+	void InitializeBrokerStoreForwarding();
+	// Check if a Broker store is associated to a table on the Zeek side.
+	void PrepareForwarding(const std::string& name);
+	// Send the content of a Broker store to the backing table. This is typically used
+	// when a master/clone is created.
+	void BrokerStoreToZeekTable(const std::string& name, const detail::StoreHandleVal* handle);
 
 	void Error(const char* format, ...)
 		__attribute__((format (printf, 2, 3)));
@@ -360,7 +396,7 @@ private:
 	};
 
 	// Data stores
-	using query_id = std::pair<broker::request_id, StoreHandleVal*>;
+	using query_id = std::pair<broker::request_id, detail::StoreHandleVal*>;
 
 	struct query_id_hasher {
 		size_t operator()(const query_id& qid) const
@@ -375,27 +411,40 @@ private:
 	std::vector<LogBuffer> log_buffers; // Indexed by stream ID enum.
 	std::string default_log_topic_prefix;
 	std::shared_ptr<BrokerState> bstate;
-	std::unordered_map<std::string, StoreHandleVal*> data_stores;
-	std::unordered_map<query_id, StoreQueryCallback*,
+	std::unordered_map<std::string, detail::StoreHandleVal*> data_stores;
+	std::unordered_map<std::string, TableValPtr> forwarded_stores;
+	std::unordered_map<query_id, detail::StoreQueryCallback*,
 	                   query_id_hasher> pending_queries;
 	std::vector<std::string> forwarded_prefixes;
 
 	Stats statistics;
 
 	uint16_t bound_port;
-	bool reading_pcaps;
-	bool after_zeek_init;
+	bool use_real_time;
 	int peer_count;
 
 	size_t log_batch_size;
 	Func* log_topic_func;
-	VectorType* vector_of_data_type;
+	VectorTypePtr vector_of_data_type;
 	EnumType* log_id_type;
 	EnumType* writer_id_type;
+	bool zeek_table_manager = false;
+	std::string zeek_table_db_directory;
 
 	static int script_scope;
 };
 
-} // namespace bro_broker
+} // namespace Broker
 
-extern bro_broker::Manager* broker_mgr;
+extern Broker::Manager* broker_mgr;
+
+} // namespace zeek
+
+extern zeek::Broker::Manager*& broker_mgr [[deprecated("Remove in v4.1. Use zeek::broker_mgr.")]];
+
+namespace bro_broker {
+
+using Stats [[deprecated("Remove in v4.1. Use zeek::Broker::Stats.")]] = zeek::Broker::Stats;
+using Manager [[deprecated("Remove in v4.1. Use zeek::Broker::Manager.")]] = zeek::Broker::Manager;
+
+} // namespace bro_broker
