@@ -1,19 +1,22 @@
+// See the file "COPYING" in the main distribution directory for copyright.
+
 #pragma once
 
-#include "Reassem.h"
+#include "zeek/Reassem.h"
 
-class BroFile;
-class Connection;
+namespace zeek { class File; }
+using BroFile [[deprecated("Remove in v4.1. Use zeek::File.")]] = zeek::File;
 
-namespace file_analysis {
+ZEEK_FORWARD_DECLARE_NAMESPACED(Connection, zeek);
+ZEEK_FORWARD_DECLARE_NAMESPACED(File, zeek, file_analysis);
 
-class File;
+namespace zeek::file_analysis {
 
-class FileReassembler : public Reassembler {
+class FileReassembler final : public Reassembler {
 public:
 
 	FileReassembler(File* f, uint64_t starting_offset);
-	~FileReassembler() override;
+	~FileReassembler() override = default;
 
 	void Done();
 
@@ -46,14 +49,19 @@ public:
 		{ return flushing; }
 
 protected:
-	FileReassembler();
 
 	void Undelivered(uint64_t up_to_seq) override;
 	void BlockInserted(DataBlockMap::const_iterator it) override;
 	void Overlap(const u_char* b1, const u_char* b2, uint64_t n) override;
 
-	File* the_file;
-	bool flushing;
+	File* the_file = nullptr;
+	bool flushing = false;
 };
 
-} // namespace analyzer::* 
+} // namespace zeek::file_analysis
+
+namespace file_analysis {
+
+using FileReassembler [[deprecated("Remove in v4.1. Use zeek::file_analysis::FileReassembler.")]] = zeek::file_analysis::FileReassembler;
+
+} // namespace file_analysis
