@@ -4,12 +4,10 @@
 
 #include <mutex>
 
-#include "plugin/Plugin.h"
+#include "zeek/plugin/Plugin.h"
+#include "zeek/input/readers/raw/Raw.h"
 
-#include "Raw.h"
-
-namespace plugin {
-namespace Zeek_RawReader {
+namespace zeek::plugin::detail::Zeek_RawReader {
 
 class Plugin : public plugin::Plugin {
 public:
@@ -29,5 +27,4 @@ private:
 
 extern Plugin plugin;
 
-}
-}
+} // namespace zeek::plugin::detail::Zeek_RawReader
